==> alg-common-1.19.38-20191218.055252-1-sources.jar: cn/com/duiba/nezha/alg/common/model/materialrecommend/MaterialDataInfo.java <==
package cn.com.duiba.nezha.alg.common.model.materialrecommend;

/**
 * @author lijingzhe
 * @description
 * @date 2019/12/12
 */
public class MaterialDataInfo {
    /**
     * 广告位素材ID
     */
    long materialId;
    /**
     * 素材标签
     */
    int materialTag;
    /**
     * 媒体ID
     */
    long appId;
    /**
     * 广告位ID
     */
    long slotId;
    /**
     * 微秒 素材创建时间
     */
    long createTime = 0;
    /**
     * 广告位素材曝光
     */
    MaterialVal exposureCnt;
    /**
     * 广告位素材点击
     */
    MaterialVal clickCnt;
    /**
     * 消耗,分
     */
    MaterialVal cost;

    public long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(long materialId) {
        this.materialId = materialId;
    }

    public int getMaterialTag() {
        return materialTag;
    }

    public void setMaterialTag(int materialTag) {
        this.materialTag = materialTag;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public MaterialVal getExposureCnt() {
        return exposureCnt;
    }

    public void setExposureCnt(MaterialVal exposureCnt) {
        this.exposureCnt = exposureCnt;
    }

    public MaterialVal getClickCnt() {
        return clickCnt;
    }

    public void setClickCnt(MaterialVal clickCnt) {
        this.clickCnt = clickCnt;
    }

    public MaterialVal getCost() {
        return cost;
    }

    public void setCost(MaterialVal cost) {
        this.cost = cost;
    }

    @Override
    public String toString() {
        return "MaterialMatchInfo{" +
                "materialId=" + materialId +
                ", materialTag=" + materialTag +
                ", appId=" + appId +
                ", slotId=" + slotId +
                ", createTime=" + createTime +
                ", exposureCnt=" + exposureCnt +
                ", clickCnt=" + clickCnt +
                ", cost=" + cost +
                '}';
    }
}

==> alg-common-2.14.0-20200509.113634-3-sources.jar: cn/com/duiba/nezha/alg/common/model/materialrecommend/MaterialDataInfo.java <==
package cn.com.duiba.nezha.alg.common.model.materialrecommend;

/**
 * @author lijingzhe
 * @description
 * @date 2019/12/12
 */
public class MaterialDataInfo {
    /**
     * algType策略类型
     */
    int algType;
    /**
     * 广告位素材ID
     */
    long materialId;
    /**
     * 结算方式(eCPM=0, uv收益导向=1)
     */
    int feeMark;
    /**
     * 素材标签
     */
    int materialTag;
    /**
     * 媒体ID
     */
    long appId;
    /**
     * 广告位ID
     */
    long slotId;
    /**
     * 微秒 素材创建时间
     */
    long createTime = 0;
    /**
     * 广告位素材曝光
     */
    MaterialVal exposureCnt = new MaterialVal();
    /**
     * 广告位素材点击
     */
    MaterialVal clickCnt = new MaterialVal();
    /**
     * 活动访问uv
     */
    MaterialVal request = new MaterialVal();
    /**
     * 消耗,分
     */
    MaterialVal cost = new MaterialVal();
    /**
     * 有效券点击次数
     */
    MaterialVal validClick = new MaterialVal();

    public int getAlgType() {
        return algType;
    }

    public void setAlgType(int algType) {
        this.algType = algType;
    }

    public long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(long materialId) {
        this.materialId = materialId;
    }

    public int getFeeMark() {
        return feeMark;
    }

    public void setFeeMark(int feeMark) {
        this.feeMark = feeMark;
    }

    public int getMaterialTag() {
        return materialTag;
    }

    public void setMaterialTag(int materialTag) {
        this.materialTag = materialTag;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public MaterialVal getExposureCnt() {
        return exposureCnt;
    }

    public void setExposureCnt(MaterialVal exposureCnt) {
        this.exposureCnt = exposureCnt;
    }

    public MaterialVal getClickCnt() {
        return clickCnt;
    }

    public void setClickCnt(MaterialVal clickCnt) {
        this.clickCnt = clickCnt;
    }

    public MaterialVal getRequest() {
        return request;
    }

    public void setRequest(MaterialVal request) {
        this.request = request;
    }

    public MaterialVal getCost() {
        return cost;
    }

    public void setCost(MaterialVal cost) {
        this.cost = cost;
    }

    public MaterialVal getValidClick() {
        return validClick;
    }

    public void setValidClick(MaterialVal validClick) {
        this.validClick = validClick;
    }

    @Override
    public String toString() {
        return "MaterialDataInfo{" +
                "algType=" + algType +
                ", materialId=" + materialId +
                ", feeMark=" + feeMark +
                ", materialTag=" + materialTag +
                ", appId=" + appId +
                ", slotId=" + slotId +
                ", createTime=" + createTime +
                ", exposureCnt=" + exposureCnt +
                ", clickCnt=" + clickCnt +
                ", request=" + request +
                ", cost=" + cost +
                ", validClick=" + validClick +
                '}';
    }
}
